from typing import Callable, List
import re
import random
import requests




def EDSG(lessonname: str, prompt: str, kb_path: str, llm: Callable) -> List[str]:
    def read_json_content(json_file, lesson_name, sub_keyword=None, inner_key=None):
        """
        读取JSON文件中特定课文下的关键字和子关键字的内容。

        参数:
        json_file (str): JSON文件路径。
        lesson_name (str): 课文名。
        sub_keyword (str): 子关键字，可选。
        inner_key (str): 内部关键字，可选。

        返回:
        任意类型: 返回匹配的内容，如果未找到匹配的关键字则返回 None。
        """
        with open(json_file, 'r', encoding='utf-8') as f:
            data = json.load(f)

        if lesson_name not in data:
            return None

        result = data[lesson_name]

        if sub_keyword:
            if sub_keyword not in result:
                return None
            result = result[sub_keyword]

            if inner_key:
                if isinstance(result, dict) and inner_key in result:
                    return result[inner_key]
                else:
                    return None

        return result

    def get_random_element(elements):
        if elements:
            return random.choice(elements)
        return None

    '''def jxmb_and_qjcs(text):
        # 随机选择一个元素
        selected_markdown = random.choice(text)

        # 使用正则表达式找到教学目标和教学活动之间的内容
        teaching_objectives = re.search(r'# 二、教学目标\s*(.*?)\s*# 三、教学活动', selected_markdown, re.S)
        teaching_objectives_content = teaching_objectives.group(1).strip() if teaching_objectives else "未找到教学目标内容"

        # 使用正则表达式找到真实情境创设和学习任务设置之间的内容
        real_context = re.search(r'## 真实情境\s*(.*?)\s*# 学习任务设置', selected_markdown, re.S)
        real_context_content = real_context.group(1).strip() if real_context else "未找到真实情境创设内容"
        教学目标=teaching_objectives_content
        真实情境创设=real_context_content
        return 教学目标,真实情境创设
    '''




    def jxmb_and_qjcs(text):
        text=str(text)
        # 分析并提取所有一级标题下的内容
        sections = re.findall(r'# (.*?)\n(.*?)#', text, re.S)
        sections_dict = {sec[0].strip(): sec[1].strip() for sec in sections}

        # 随机选择一个一级标题下的内容
        fallback_content = random.choice(list(sections_dict.values())) if sections_dict else "没有找到任何一级标题内容"

        # 使用正则表达式找到教学目标和教学活动之间的内容
        teaching_objectives = re.search(r'# 二、教学目标\s*(.*?)\s*# 三、教学活动', text, re.S)
        if teaching_objectives:
            教学目标 = teaching_objectives.group(1).strip()
        else:
            教学目标 = fallback_content

        # 使用正则表达式找到真实情境创设和学习任务设置之间的内容
        real_context = re.search(r'# 真实情境创设\s*(.*?)\s*# 学习任务设置', text, re.S)
        if real_context:
            真实情境创设 = real_context.group(1).strip()
        else:
            真实情境创设 = fallback_content

        return 教学目标, 真实情境创设



    def Rewrite(lessonname,text):
        prompt="""现在你是一名语文教学领域的学科专家，下列文字是关于课文《"""+lessonname+"""》教学设计中的部分内容，请根据以下文字，重写以提升准确性、清晰度和连贯性，同时保持原意不变。重写后的版本应采用不同的表达方式，使文字更加准确，且思想的连贯性更强。\n\n原文:\n"""+text +"\n注意：输出结果为重写后的文字，输出结果中不要出现“重写、改写、修订”等相关的字眼" 
        messages=[
                    {"role": "system", "content": "现在你是一名语文教学领域的学科专家，你需要对教学设计中的相关文字进行重写以提升准确性、清晰度和连贯性，同时保持原意不变。重写后的版本应采用不同的表达方式，使文字更加准确，且思想的连贯性更强。"
                },
                    {"role": "user", "content": prompt}  # 当前用户提示
                ]
        response=llm(messages)
        return response

    def Rewritewithprom(lessonname,text,PROMPT):
        prompt="""现在你是一名语文教学领域的学科专家，下列文字是关于课文《"""+lessonname+"""》教学设计中的部分内容，请根据以下文字，重写以提升准确性、清晰度和连贯性，同时保持原意不变。重写后的版本应采用不同的表达方式，使文字更加准确，且思想的连贯性更强。\n\n原文:\n"""+text +"\n注意：" +PROMPT
        messages=[
                    {"role": "system", "content": "现在你是一名语文教学领域的学科专家，你需要对教学设计中的相关文字进行重写以提升准确性、清晰度和连贯性，同时保持原意不变。重写后的版本应采用不同的表达方式，使文字更加准确，且思想的连贯性更强。"
                },
                    {"role": "user", "content": prompt}  # 当前用户提示
                ]
        response=llm(messages)
        return response


    def Separation_of_tasks(text):
        fewshot="""现在你需要从一段文字中分离出任务，下面的例子可作为该任务的参照：
        输入：在语文教学中，我们借鉴戏剧大师焦菊隐的观点，强调将舞台的有限性转化为艺术的无限可能，这同样适用于文学作品的解读与再创作。对于经典如茅盾的《百合花》，其成功改编的关键在于精准捕捉人物塑造的核心与作品主题的灵魂。茅盾评价《百合花》的人物描绘细腻入微，如同渐进的视觉揭示，既显外在形貌，又现内在情感，风格清新且结构严谨，富有诗意。因此，深入剖析《百合花》的人物塑造与抒情表达，是理解作品、进行戏剧改编的基石。随着学校戏剧艺术节的到来，戏剧社的同学计划改编《百合花》为课本剧。为了助演员洞悉角色，提升表演质量，他们需分步骤完成以下任务：首先，进行“人物深度挖掘”——同学们需撰写600至800字的“典型人物剧本”，围绕主要角色展开深入剖析，逻辑清晰地阐述角色特性，并在小组内分享讨论。其次，关注“细节的艺术呈现”——以“物象艺术表达”为主题，创作600至800字的“场景创作札记”，要求条理分明，展现对环境和道具如何服务于主题的理解，小组内进行汇报交流。最后，提炼“主题精髓”——编写一份600至800字的“主题宣传手册”，围绕百合花的象征意蕴，创新性地阐述作品主题，确保内容有据可循，以便在班级展示时吸引观众共鸣。总之，通过对《百合花》的深入研究，同学们将在实际操作中学会如何通过人物塑造和艺术细节，生动传达作品的核心价值。
        注意：输出格式为：1."任务内容"2."任务内容"3."任务内容"
        输出：
        1.首先，进行“人物深度挖掘”——同学们需撰写600至800字的“典型人物剧本”，围绕主要角色展开深入剖析，逻辑清晰地阐述角色特性，并在小组内分享讨论。
        2.其次，关注“细节的艺术呈现”——以“物象艺术表达”为主题，创作600至800字的“场景创作札记”，要求条理分明，展现对环境和道具如何服务于主题的理解，小组内进行汇报交流。
        3.最后，提炼“主题精髓”——编写一份600至800字的“主题宣传手册”，围绕百合花的象征意蕴，创新性地阐述作品主题，确保内容有据可循，以便在班级展示时吸引观众共鸣。

        输入：马尔克斯曾言：“生活的意义在于叙述，通过讲述来证实我们的存在。”在文学世界中，人物的命运揭示了作者的存在价值，而读者则通过解读角色，验证他们的生活痕迹。深入理解小说，首要之务便是剖析人物，尤其是《百合花》中鲜活立体的角色，这不仅是通晓小说的起点，也是文学作品精髓所在。人物塑造的成功，不仅能提升作品的艺术感染力，还丰富了主题内涵，甚至可能成为作品与作者不可磨灭的记忆符号。为此，我们班级新设立了文学主题期刊，以“当时与此刻”为主题，鼓励全体同学参与，特别是诗歌创作。首先，为了引导同学们更深入地领悟《百合花》，请每位学生选择文中一人，依据其言行描绘（包括语言、神态和外貌），撰写一份400至500字的详尽人物特写。在小组内交流讨论，共同打磨，然后选出代表进行全班分享。其次，要求你们从自然环境和社会风俗的描绘入手，探究《百合花》的散文特质。挑选一两个实例，撰写200至300字的文本，阐述小说如何运用散文化手法。这种分析将有助于你们在诗歌创作中捕捉小说的独特韵味。最后，将你们的人物小传转化为诗歌，围绕“当时与此刻”的主题展开创作。在诗作中，要捕捉“我”和新媳妇情感变化的线索，挖掘《百合花》中的象征意象，以此探索小说的核心主题。诗歌创作不限字数，但务必紧贴主题，展现对文本的深刻理解。记住，每一次文字转化都是对原著的理解深化，期待你们在这一过程中，既提升文学素养，又发掘自我表达的能力。
        注意：输出格式为：1."任务内容"2."任务内容"3."任务内容"
        输出：
        1.为此，我们班级新设立了文学主题期刊，以“当时与此刻”为主题，鼓励全体同学参与，特别是诗歌创作。首先，为了引导同学们更深入地领悟《百合花》，请每位学生选择文中一人，依据其言行描绘（包括语言、神态和外貌），撰写一份400至500字的详尽人物特写。在小组内交流讨论，共同打磨，然后选出代表进行全班分享。
        2.其次，要求你们从自然环境和社会风俗的描绘入手，探究《百合花》的散文特质。挑选一两个实例，撰写200至300字的文本，阐述小说如何运用散文化手法。这种分析将有助于你们在诗歌创作中捕捉小说的独特韵味。
        3.最后，将你们的人物小传转化为诗歌，围绕“当时与此刻”的主题展开创作。在诗作中，要捕捉“我”和新媳妇情感变化的线索，挖掘《百合花》中的象征意象，以此探索小说的核心主题。诗歌创作不限字数，但务必紧贴主题，展现对文本的深刻理解。

        输入：为了深化学生对文学作品的理解，我们将遵循陈忠实的观点，理解小说作为民族历史镜像的重要性，特别是通过《百合花》这一篇章，探索爱情、战争等核心主题。战争，尽管是人类文明的冲突缩影，但小说家们运用各种手法揭示其复杂性，有的侧重揭示战争的残酷，有的则聚焦其中的人性光辉。正如亚里士多德所述，战争既是英雄的舞台，也是普通人的磨难。在国庆74周年之际，我们学校语文部将以“讲述英雄故事，庆祝国家荣光”为主题开展讲故事活动，各班级需选用课本中的红色故事参与。针对《百合花》的评析，学生们将从三个关键维度展开：一是“叙述视角的解读”，他们需撰写一篇400字的评论，深入分析小说中第一人称和女性视角的应用，阐述不同视角如何影响故事的呈现，并在小组讨论中整合观点，探讨这两者如何塑造独特的叙事效果。二是“细节描写的剖析”，学生们需撰写一篇关于人物塑造的400字评析，具体分析通讯员和新媳妇的形象是如何通过细腻的细节展现出来的。他们需要借鉴文本技巧，结合实际生活经验，尝试描绘身边的人物。三是“象征艺术的探讨”，学生们需围绕百合花的象征含义撰写一篇400字的评析，思考其在情感表达和人性揭示中的作用，并在小组讨论中共同揭示小说中情感美和人性美的深层内涵。这些任务旨在引导学生深入挖掘《百合花》的艺术魅力，提升他们的批判性思维和文学鉴赏能力。
        注意：输出格式为：1."任务内容"2."任务内容"3."任务内容"
        输出：
        1.一是“叙述视角的解读”，他们需撰写一篇400字的评论，深入分析小说中第一人称和女性视角的应用，阐述不同视角如何影响故事的呈现，并在小组讨论中整合观点，探讨这两者如何塑造独特的叙事效果。
        2.二是“细节描写的剖析”，学生们需撰写一篇关于人物塑造的400字评析，具体分析通讯员和新媳妇的形象是如何通过细腻的细节展现出来的。他们需要借鉴文本技巧，结合实际生活经验，尝试描绘身边的人物。
        3.三是“象征艺术的探讨”，学生们需围绕百合花的象征含义撰写一篇400字的评析，思考其在情感表达和人性揭示中的作用，并在小组讨论中共同揭示小说中情感美和人性美的深层内涵。

        输入：作为语文教育专家，我们强调文学作品的社会镜像功能。沙汀曾言：“小说是社会生活的写照。”《百合花》正是这种理念的生动例证，它植根于现实，通过战争背景揭示复杂的社会景观和个人情感深度，验证了“文学源于人，亦反映人”的理念。这部作品在战乱中独具魅力，以其“没有爱情的爱情牧歌”形式，展现了小战士的崇高品格和人与人之间的深厚情谊，以及对和平与人性美德的呼唤。为了深化学生对“文学与人学”关系的理解，学校文学社策划了一期专题栏目，聚焦“小说中的典型人物形象”。我们以《百合花》为核心，探讨人物塑造、叙事技巧与主题内涵，剖析其如何以艺术手法深刻影响社会生活。为此，每位同学需完成三个主题的读书笔记：1. “人物的画卷”——请以《百合花》中的人物塑造为切入点，撰写一篇600至800字的评论，要求逻辑清晰，观点鲜明，便于小组讨论分享你的观察和理解。2. “编织故事的艺术”——以小说的叙述视角和结构设计为主题，撰写一篇600至800字的分析札记，阐述作者如何运用这些元素来构建故事，鼓励你在小组中展示并交流你的思考。3. “战争中的和谐旋律”——针对百合花象征的人性光辉，撰写一篇600至800字的深度解读，要求层次分明，见解独到，以便在小组讨论时展现你的深度洞察。注意，你们的任务是通过对这些文本的深入研读，提升文学鉴赏能力，而非简单修订或修改。
        注意：输出格式为：1."任务内容"2."任务内容"3."任务内容"
        输出：
        1.1. “人物的画卷”——请以《百合花》中的人物塑造为切入点，撰写一篇600至800字的评论，要求逻辑清晰，观点鲜明，便于小组讨论分享你的观察和理解。
        2.2. “编织故事的艺术”——以小说的叙述视角和结构设计为主题，撰写一篇600至800字的分析札记，阐述作者如何运用这些元素来构建故事，鼓励你在小组中展示并交流你的思考。
        3.3. “战争中的和谐旋律”——针对百合花象征的人性光辉，撰写一篇600至800字的深度解读，要求层次分明，见解独到，以便在小组讨论时展现你的深度洞察。

        输入：在我们的语文教学实践中，我们重视通过文学作品如沙汀所言的现实映射，特别是《百合花》这样反映战时生活的杰作，它以独特笔触揭示了人性的多元和社会的深邃。这部作品通过描绘普通士兵的英勇行为，展现了战争中超越冲突的纯真情感纽带以及对和平与美德的深刻追求。为了深化“文学与生活”的融合理解，我们文学社策划了一项“人物与情节探索”主题研究项目。首先，学生需撰写一篇名为“《百合花》人物塑造与内涵解读”的详尽论文，字数限定在600至800字，鼓励小组协作，以集体智慧深入探讨人物塑造的艺术手法。紧接着，学生们将参与“叙事技巧研讨”，要求编写一篇“叙事策略与结构剖析”笔记，专攻视角选择与情节构建，同样需保持逻辑清晰，字数区间为600至800字，以促进团队内部的深度交流和批判性思考。最后，他们需要完成一篇“战争中的情感共鸣与人性启示”札记，重点关注“百合花象征的人性光辉”这一核心主题，要求分析深入，字数控制在600至800字。通过小组分享和讨论，我们旨在引导学生领悟艺术如何以小说的形式揭示社会现实，从而提升他们对文学作品的鉴赏力和深层次理解。这个系列实践活动旨在全方位引导学生解读文本，深化他们对社会现象和人性本质的认识。
        注意：输出格式为：1."任务内容"2."任务内容"3."任务内容"
        输出：
        1.为了深化“文学与生活”的融合理解，我们文学社策划了一项“人物与情节探索”主题研究项目。首先，学生需撰写一篇名为“《百合花》人物塑造与内涵解读”的详尽论文，字数限定在600至800字，鼓励小组协作，以集体智慧深入探讨人物塑造的艺术手法。
        2.紧接着，学生们将参与“叙事技巧研讨”，要求编写一篇“叙事策略与结构剖析”笔记，专攻视角选择与情节构建，同样需保持逻辑清晰，字数区间为600至800字，以促进团队内部的深度交流和批判性思考。
        3.最后，他们需要完成一篇“战争中的情感共鸣与人性启示”札记，重点关注“百合花象征的人性光辉”这一核心主题，要求分析深入，字数控制在600至800字。通过小组分享和讨论，我们旨在引导学生领悟艺术如何以小说的形式揭示社会现实，从而提升他们对文学作品的鉴赏力和深层次理解。这个系列实践活动旨在全方位引导学生解读文本，深化他们对社会现象和人性本质的认识。
        """
        prompt=fewshot+text+"""\n注意：输出格式为：1."任务内容"\n2."任务内容"\n3."任务内容" """ 
        messages=[
                    {"role": "system", "content": "现在你需要从一段文字中分离出三个任务，并将这三个任务进行标识"
                },
                    {"role": "user", "content": prompt}  # 当前用户提示
                ]
        response=llm(messages)
        return response


    def Separation_of_Ques(text):
        fewshot="""现在你需要从一段文字中分离出问题，下面的例子可作为该任务的参照：
        输入：学习任务：重现经典场景。同学们通过场景设计，选择小说中有代表性的、打动人的场景，进行《百合花》小说布景搭建，并撰写400-500字的布景札记，阐述场景选择及设计理念，要求条理清晰，结构严谨。
        问题：
        问题1：小说主要以“我”的视角讲述了一天一夜内前沿包扎所一位小通讯员和一位农村新媳妇发生的一些故事。微电影拍摄需要熟悉小说情节与场景，请你在阅读文本后自主进行情节概括并指出哪些情节是推动故事发展的关键节点?
        问题2：小说中有许多关键的、打动人的场景，拍摄微电影时重现这些场景。请你仔细阅读文本，尝试找出至少三个你认为最为关键且打动人心的场景，并简要分析每个场景在小说中的作用。
        问题3：选择其中一个关键场景，围绕场景布置、镜头运用和角色调度等角度重现场景，并说明理由。
        注意：输出格式为：问题1:"问题内容"问题2:"问题内容"问题3:"问题内容"
        输出:
        问题1：小说主要以“我”的视角讲述了一天一夜内前沿包扎所一位小通讯员和一位农村新媳妇发生的一些故事。微电影拍摄需要熟悉小说情节与场景，请你在阅读文本后自主进行情节概括并指出哪些情节是推动故事发展的关键节点?
        问题2：小说中有许多关键的、打动人的场景，拍摄微电影时重现这些场景。请你仔细阅读文本，尝试找出至少三个你认为最为关键且打动人心的场景，并简要分析每个场景在小说中的作用。
        问题3：选择其中一个关键场景，围绕场景布置、镜头运用和角色调度等角度重现场景，并说明理由。

        输入：学习任务：制作角色小卡。从《百合花》中主要演员的妆容、造型和表演技巧等方面，制作500字的“角色介绍卡”，内容包括角色名字及背景、分析角色性格特点、情感变化、主题表现等。
        问题：
        问题1：确定好拍摄场景后，需要明确微电影角色。请初步阅读文本，说说小说中主要有哪几个人物？
        问题2：“角色小卡”将从主要演员角色背景、性格特点、情感变化等方面制作，结合具体情节补充“角色小卡”概括小通讯员、新媳妇和“我”的形象。
        问题3：小说中，“我”对通讯员的态度、新媳妇对通讯员的态度发生了多次变化。这些情感的变化是怎样的，对人物的性格表达又有怎样的作用呢？请结合文本谈谈你的理解。  
        注意：输出格式为：问题1:"问题内容"问题2:"问题内容"问题3:"问题内容"
        输出:
        问题1：确定好拍摄场景后，需要明确微电影角色。请初步阅读文本，说说小说中主要有哪几个人物？
        问题2：“角色小卡”将从主要演员角色背景、性格特点、情感变化等方面制作，结合具体情节补充“角色小卡”概括小通讯员、新媳妇和“我”的形象。
        问题3：小说中，“我”对通讯员的态度、新媳妇对通讯员的态度发生了多次变化。这些情感的变化是怎样的，对人物的性格表达又有怎样的作用呢？请结合文本谈谈你的理解。  

        输入：学习任务：选择拍摄道具。搜集和制作能够反映《百合花》时代特征和人物性格的道具，撰写400字左右的“道具介绍”文案，讲解其背后的故事及其在电影中如何运用。
        问题：
        问题1：百合花作为贯穿小说的意象，微电影拍摄的道具首先选择和百合花有关的物件。请你结合文本概括“百合花”共出现了几次？每次出现分别是在什么情节中?
        问题2：借被和献被这两个情节都出现了“百合花被”这一物件，借被时还特写被子外形“这原来是一条里外全新的新花被子，被面是假洋缎的，枣红底，上面撒满白色百合花。”反复提到“百合花被”与人物性格的表达有何关联？
        问题3：文中除了百合花被，还出现了如干硬的馒头、小通讯员步枪筒里的树枝和野菊花和服刮破后的布片和破洞等细节事物，请你完善“细节事物与人物形象”表格，注意它们与人物之间的关联,分析这样的细节描写有什么作用。
        注意：输出格式为：问题1:"问题内容"问题2:"问题内容"问题3:"问题内容"
        输出:
        问题1：百合花作为贯穿小说的意象，微电影拍摄的道具首先选择和百合花有关的物件。请你结合文本概括“百合花”共出现了几次？每次出现分别是在什么情节中?
        问题2：借被和献被这两个情节都出现了“百合花被”这一物件，借被时还特写被子外形“这原来是一条里外全新的新花被子，被面是假洋缎的，枣红底，上面撒满白色百合花。”反复提到“百合花被”与人物性格的表达有何关联？
        问题3：文中除了百合花被，还出现了如干硬的馒头、小通讯员步枪筒里的树枝和野菊花和服刮破后的布片和破洞等细节事物，请你完善“细节事物与人物形象”表格，注意它们与人物之间的关联,分析这样的细节描写有什么作用。

        输入：学习任务：“《百合花》与叙述视角” 评议。同学们需要以“《百合花》与叙述视角”为出发点，写一篇400字左右的评议说明，要求呈现自己对《百合花》中叙述视角的思考，阐明不同叙述视角的作用，言之成理即可；在小组讨论中汇总个人发现，并对小说中第一人称视角和女性视角的运用进行探讨，形成完整的评议说明。
        问题：
        问题1：我们在小学时已经学过一篇战争题材的小说《狼牙山五壮士》，里面描写的战争令人难忘。同写战争，《狼牙山五壮士》和《百合花》中写战争在选材和写法上有什么不同？
        问题2：讲故事的人是谁？这样处理有什么好处？
        问题3：同为女性，为什么要用“我”的视角来讲故事，而不用新媳妇的视角来讲故事呢？
        注意：输出格式为：问题1:"问题内容"问题2:"问题内容"问题3:"问题内容"
        输出:
        问题1：我们在小学时已经学过一篇战争题材的小说《狼牙山五壮士》，里面描写的战争令人难忘。同写战争，《狼牙山五壮士》和《百合花》中写战争在选材和写法上有什么不同？
        问题2：讲故事的人是谁？这样处理有什么好处？
        问题3：同为女性，为什么要用“我”的视角来讲故事，而不用新媳妇的视角来讲故事呢？    

        输入：学习任务：《百合花》与细节描写” 评议。同学们需要以“《百合花》与细节描写”为出发点写一篇400字左右的评议说明，梳理小说在塑造人物形象时所用的细节描写，言之成理即可；在小组讨论中汇总个人发现，并对小说中通讯员和新媳妇的人物形象进行探讨，形成完整的评议说明；仿照本文塑造人物形象的方法，结合真实生活体验，对身边的人物进行描写。
        问题：
        问题1：小说中前后呼应的细节刻画，在全篇中非常精彩。结合示例分析下表中细节描写对表现人物的具体作用。
        问题2：文中新媳妇这个角色是如何一步一步转变的？请结合对新媳妇的细节描写简要分析。
        问题3：写小通讯员时，小说还插入了想象小通讯员背毛竹的场景，及插入故乡中秋节乡俗时拟想小通讯员在前线的情景，为什么要这样写？
        注意：输出格式为：问题1:"问题内容"问题2:"问题内容"问题3:"问题内容"
        输出:
        问题1：我们在小学时已经学过一篇战争题材的小说《狼牙山五壮士》，里面描写的战争令人难忘。同写战争，《狼牙山五壮士》和《百合花》中写战争在选材和写法上有什么不同？
        问题2：讲故事的人是谁？这样处理有什么好处？
        问题3：同为女性，为什么要用“我”的视角来讲故事，而不用新媳妇的视角来讲故事呢？  
        """
        prompt=fewshot+text+"""\n注意：输出格式为：问题1:"问题内容"问题2:"问题内容"问题3:"问题内容" """ 
        messages=[
                    {"role": "system", "content": "现在你需要从一段文字中分离出三个问题，并将这三个问题进行标识"
                },
                    {"role": "user", "content": prompt}  # 当前用户提示
                ]
        response=llm(messages)
        return response

    def extract_questions(text):
        # 移除多余的换行符并去除前后空格
        text = text.strip()

        # 第一步：使用正则表达式匹配带有问号的句子，主要依据"问题"关键词
        questions = re.findall(r'问题\d(.*?\?)', text)

        # 第二步：如果找到的不足三个问题，使用换行符分隔符来检测
        if len(questions) < 3:
            questions = re.split(r'\n+', text)

        # 如果还是不足三个问题，则将检测到的问题补足到三个
        while len(questions) < 3:
            questions.append(text)

        # 返回确保有三个问题的列表
        return questions[:3]



    def extract_tasks(output: str) -> list:
        """
        从给定的输出字符串中提取任务并存储在一个列表中。

        参数:
        output (str): 包含任务内容的字符串。

        返回:
        list: 包含分离出的任务的列表，确保有3个元素。
        """
        # 使用正则表达式匹配每个任务
        tasks = re.findall(r'\d+\.\s*(.*?)\s*(?=\d+\.|$)', output, re.DOTALL)

        # 去除多余的空白并存储到列表中
        tasks_list = [task.strip() for task in tasks]

        # 检查 tasks_list 的长度，确保至少有 3 个元素
        while len(tasks_list) < 3:
            tasks_list.append(output.strip())  # 将整个输入字符串作为任务之一

        return tasks_list

    def QG(Learning_tasks,lessonname):
        few_shot= """现在你需要从高中语文课文：《"""+lessonname+"""》的教学设计中的关于"学习任务"生成对应的三个相关问题，下面的例子可作为该任务的参照：
        学习任务：重现经典场景。同学们通过场景设计，选择小说中有代表性的、打动人的场景，进行《百合花》小说布景搭建，并撰写400-500字的布景札记，阐述场景选择及设计理念，要求条理清晰，结构严谨。
        注意：考虑问题与学习任务之间的关联性，输出格式为：问题：问题1：'问题内容'问题2：'问题内容'问题3：'问题内容'。
        问题：
        问题1：小说主要以“我”的视角讲述了一天一夜内前沿包扎所一位小通讯员和一位农村新媳妇发生的一些故事。微电影拍摄需要熟悉小说情节与场景，请你在阅读文本后自主进行情节概括并指出哪些情节是推动故事发展的关键节点?
        问题2：小说中有许多关键的、打动人的场景，拍摄微电影时重现这些场景。请你仔细阅读文本，尝试找出至少三个你认为最为关键且打动人心的场景，并简要分析每个场景在小说中的作用。
        问题3：选择其中一个关键场景，围绕场景布置、镜头运用和角色调度等角度重现场景，并说明理由。

        学习任务：制作角色小卡。从《百合花》中主要演员的妆容、造型和表演技巧等方面，制作500字的“角色介绍卡”，内容包括角色名字及背景、分析角色性格特点、情感变化、主题表现等。
        注意：考虑问题与学习任务之间的关联性，输出格式为：问题：问题1：'问题内容'问题2：'问题内容'问题3：'问题内容'。
        问题：
        问题1：确定好拍摄场景后，需要明确微电影角色。请初步阅读文本，说说小说中主要有哪几个人物？
        问题2：“角色小卡”将从主要演员角色背景、性格特点、情感变化等方面制作，结合具体情节补充“角色小卡”概括小通讯员、新媳妇和“我”的形象。
        问题3：小说中，“我”对通讯员的态度、新媳妇对通讯员的态度发生了多次变化。这些情感的变化是怎样的，对人物的性格表达又有怎样的作用呢？请结合文本谈谈你的理解。  

        学习任务：选择拍摄道具。搜集和制作能够反映《百合花》时代特征和人物性格的道具，撰写400字左右的“道具介绍”文案，讲解其背后的故事及其在电影中如何运用。
        注意：考虑问题与学习任务之间的关联性，输出格式为：问题：问题1：'问题内容'问题2：'问题内容'问题3：'问题内容'。
        问题：
        问题1：百合花作为贯穿小说的意象，微电影拍摄的道具首先选择和百合花有关的物件。请你结合文本概括“百合花”共出现了几次？每次出现分别是在什么情节中?
        问题2：借被和献被这两个情节都出现了“百合花被”这一物件，借被时还特写被子外形“这原来是一条里外全新的新花被子，被面是假洋缎的，枣红底，上面撒满白色百合花。”反复提到“百合花被”与人物性格的表达有何关联？
        问题3：文中除了百合花被，还出现了如干硬的馒头、小通讯员步枪筒里的树枝和野菊花和服刮破后的布片和破洞等细节事物，请你完善“细节事物与人物形象”表格，注意它们与人物之间的关联,分析这样的细节描写有什么作用。

        学习任务：“《百合花》与叙述视角” 评议。同学们需要以“《百合花》与叙述视角”为出发点，写一篇400字左右的评议说明，要求呈现自己对《百合花》中叙述视角的思考，阐明不同叙述视角的作用，言之成理即可；在小组讨论中汇总个人发现，并对小说中第一人称视角和女性视角的运用进行探讨，形成完整的评议说明。
        注意：考虑问题与学习任务之间的关联性，输出格式为：问题：问题1：'问题内容'问题2：'问题内容'问题3：'问题内容'。
        问题：
        问题1：我们在小学时已经学过一篇战争题材的小说《狼牙山五壮士》，里面描写的战争令人难忘。同写战争，《狼牙山五壮士》和《百合花》中写战争在选材和写法上有什么不同？
        问题2：讲故事的人是谁？这样处理有什么好处？
        问题3：同为女性，为什么要用“我”的视角来讲故事，而不用新媳妇的视角来讲故事呢？

        学习任务：《百合花》与细节描写” 评议。同学们需要以“《百合花》与细节描写”为出发点写一篇400字左右的评议说明，梳理小说在塑造人物形象时所用的细节描写，言之成理即可；在小组讨论中汇总个人发现，并对小说中通讯员和新媳妇的人物形象进行探讨，形成完整的评议说明；仿照本文塑造人物形象的方法，结合真实生活体验，对身边的人物进行描写。
        注意：考虑问题与学习任务之间的关联性，输出格式为：问题：问题1：'问题内容'问题2：'问题内容'问题3：'问题内容'。
        问题：
        问题1：小说中前后呼应的细节刻画，在全篇中非常精彩。结合示例分析下表中细节描写对表现人物的具体作用。
        问题2：文中新媳妇这个角色是如何一步一步转变的？请结合对新媳妇的细节描写简要分析。
        问题3：写小通讯员时，小说还插入了想象小通讯员背毛竹的场景，及插入故乡中秋节乡俗时拟想小通讯员在前线的情景，为什么要这样写？

        """

        prompt=few_shot+Learning_tasks+"\n注意：考虑问题与学习任务之间的关联性，输出格式为：问题：\n问题1：'问题内容'问题2：'问题内容'问题3：'问题内容'。" 
        messages=[
                    {"role": "system", "content": "现在你是一名语文学科专家，现在你需要对学习任务一步一步生成三个学习问题。注意：考虑问题与学习任务之间的关联性。"
                },
                    {"role": "user", "content": prompt}  # 当前用户提示
                ]
        response=llm(messages)
        return response





    def check_and_remove_string_in_csv(filename, target_string):
        found = False
        if os.path.exists(filename):
            # 读取CSV文件内容
            with open(filename, newline='') as csvfile:
                reader = csv.reader(csvfile)
                rows = [row for row in reader if row and row[0] != target_string]  # 过滤掉目标字符串的行

            # 检查是否找到了目标字符串
            if len(rows) < sum(1 for _ in csv.reader(open(filename, newline=''))):
                found = True

            # 如果找到了目标字符串，将更新后的内容写回CSV文件
            if found:
                with open(filename, 'w', newline='') as csvfile:
                    writer = csv.writer(csvfile)
                    writer.writerows(rows)

        return found



    # 生成教学互动
    def jxhd(_merged_list,_id):


        # 生成教学互动的函数
        def function(questions):
            # 将问题数组合并为字符串，使用换行符分隔
            questions_str = "\na\n".join(questions)

            # 调用请求处理函数，发送 HTTP 请求
            response = send_request(questions_str)

            # 返回请求的响应结果
            return response

        # 处理请求的函数
        def send_request(questions):
            url = "http://192.168.8.66:9999/process"
            data = {
                "questions": questions,
            }
            response = requests.post(url, json=data)

            # 检查请求是否成功
            if response.status_code == 200:
                try:
                    json_data = response.json()  # 解析为JSON对象
                    # 只返回response对应的内容
                    return json_data.get("response", "No response content found")
                except json.JSONDecodeError as e:
                    print(f"JSON解析错误: {e}")
                    return response.text  # 返回未解码的文本内容
            else:
                return f"Error: {response.status_code}\n{response.text}"

        # 将result转换为数组
        def parse_result_to_array(result):
            result = result.replace(' ', '')
            # 使用正则表达式匹配特定符号作为分隔符
            questions = re.split(r'\["|\[\'|\'\]|"\]|\',\'|","|\',"|\',"', result)

            # 去除空白字符和空字符串
            questions = [q.strip() for q in questions if q.strip()]

            return questions

        # 假设 result 是包含特定分隔符的字符串
        # 将 result 转换为数组
        questions_array = parse_result_to_array(_merged_list)

        # 生成互动
        response = function(questions_array)
        response=str(response)
        modified_string = response.replace(_id, "")
        return modified_string
    
    

    # 生成流式输出的生成器函数
    def generate_output(lessonname, prompt,kb_path):
        PROMPT = prompt
        
        


        学生基本信息 = get_random_element(read_json_content(kb_path, lessonname, '学情分析', '学生基本信息'))
        教材分析 = get_random_element(read_json_content(kb_path, lessonname, '学情分析', '教材分析'))
        课标分析 = get_random_element(read_json_content(kb_path, lessonname, '学情分析', '课标分析'))
        教学重难点 = get_random_element(read_json_content(kb_path, lessonname, '教学重难点'))
        教学方法 = get_random_element(read_json_content(kb_path, lessonname, '教学方法'))
        作业设计 = get_random_element(read_json_content(kb_path, lessonname, '教学评价', '作业设计'))
        内置模板 = read_json_content(kb_path, lessonname, '内置模板')
        教学目标 = jxmb_and_qjcs(内置模板)[0]
        真实情境创设 = jxmb_and_qjcs(内置模板)[1]

       
        学生基本信息 = Rewritewithprom(lessonname, 学生基本信息,PROMPT)
        学生基本信息=学生基本信息.replace("重写后", "").replace("改写后", "").replace("修订后", "").replace("重写", "").replace("改写", "").replace("修订", "")
        教材分析 = Rewrite(lessonname, 教材分析)
        教材分析 =教材分析.replace("重写后", "").replace("改写后", "").replace("修订后", "").replace("重写", "").replace("改写", "").replace("修订", "")
        课标分析= Rewrite(lessonname, 课标分析)
        课标分析=课标分析.replace("重写后", "").replace("改写后", "").replace("修订后", "").replace("重写", "").replace("改写", "").replace("修订", "")
        教学重难点= Rewrite(lessonname, 教学重难点)
        教学重难点=教学重难点.replace("重写后", "").replace("改写后", "").replace("修订后", "").replace("重写", "").replace("改写", "").replace("修订", "")
        真实情境创设= Rewrite(lessonname, 真实情境创设)
        真实情境创设=真实情境创设.replace("重写后", "").replace("改写后", "").replace("修订后", "").replace("重写", "").replace("改写", "").replace("修订", "")
        tasks = Separation_of_tasks(真实情境创设)



        # 调用函数并打印结果
        tasks_list = extract_tasks(tasks)

        #for i, task in enumerate(tasks_list, 1):
           # print(f"任务 {i}: {task}")

        List=[]
        i=1
        for item in tasks_list:
            question=QG(item,lessonname)
            comb="\n"+"学习任务"+str(i)+"\n"+item+question
            i=i+1
            List.append(comb)

        Q=[]
        for item in List:
            Q=Q+extract_questions(Separation_of_Ques(item)) 



        # 示例任务和问题列表
        # 初始化结果列表
        merged_list = []
        # 按照特定顺序合并
        for task in tasks_list:
            merged_list.append(task)
            # 每个任务后添加三个问题
            for _ in range(3):
                merged_list.append(Q.pop(0))  # 从Q中取出第一个问题并添加

        # 输出结果
        print(merged_list)
        merged_list.append(lessonname)
        merged_list=str(merged_list)
        学习任务设置=merged_list




        教学方法= Rewrite(lessonname, 教学方法)
        教学方法=教学方法.replace("重写", "").replace("改写", "").replace("修订", "")



        作业设计= Rewrite(lessonname, 作业设计)
        作业设计=作业设计.replace("重写", "").replace("改写", "").replace("修订", "")
    





        result = [学生基本信息,教材分析,课标分析,教学目标,教学重难点,真实情境创设,学习任务设置,教学方法,作业设计]
        return result
    LIST=generate_output(lessonname, prompt,kb_path)
    return LIST
    

